aboutsummaryrefslogtreecommitdiffstats
path: root/src/rcl_cmd_args.erl
diff options
context:
space:
mode:
Diffstat (limited to 'src/rcl_cmd_args.erl')
-rw-r--r--src/rcl_cmd_args.erl6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/rcl_cmd_args.erl b/src/rcl_cmd_args.erl
index 201a7af..f12d216 100644
--- a/src/rcl_cmd_args.erl
+++ b/src/rcl_cmd_args.erl
@@ -127,11 +127,11 @@ create_goals(Opts, Acc) ->
create_output_dir(Opts, [{goals, Specs} | Acc])
end.
--spec convert_goals([string()], [depsolver:constraint()]) ->
- {ok,[depsolver:constraint()]} |
+-spec convert_goals([string()], [rcl_depsolver:constraint()]) ->
+ {ok,[rcl_depsolver:constraint()]} |
relcool:error().
convert_goals([], Specs) ->
%% Reverse the specs because order matters to depsolver
{ok, lists:reverse(Specs)};
convert_goals([RawSpec | Rest], Acc) ->
case rcl_goal:parse(RawSpec) of
@@ -127,11 +127,11 @@ create_goals(Opts, Acc) ->
relcool:error().
convert_goals([], Specs) ->
- %% Reverse the specs because order matters to depsolver
+ %% Reverse the specs because order matters to rcl_depsolver
{ok, lists:reverse(Specs)};
convert_goals([RawSpec | Rest], Acc) ->